"use client"
import React, { useEffect, useState } from 'react'
import { IoMdAddCircle } from "react-icons/io";
import useProfile from '../../components/UseProfile'
import UserTab from '../../components/layout/UserTab';
import Link from 'next/link';

const MenuItemsPage = () => {
    const {loading, data} = useProfile();
    const [menuItems, setMenuItems] = useState([]);
    
    useEffect(() => {
        fetch('/api/menu-items').then(res => {
            res.json().then(menuItems => {
                setMenuItems(menuItems);
            })
        })
    }, [])

    if(loading){
        return <p className='flex justify-center items-center'>Loading...</p>
    }
    if(!data.admin){
        return <p className='flex justify-center items-center'>Please login as an admin</p>
    }
    

  return (
    <div className='px-5 mb-10'>
        <UserTab isAdmin={true}/>
        <div className='max-w-md mx-auto mt-10'>
            <Link href={'/menu-items/new'} className='w-full border p-2 flex justify-between items-center my-2 rounded-md outline-none border-[#DCA0AE]'>Create new menu item 
                <IoMdAddCircle className='text-lg text-pink-500'/>
            </Link>
        </div>
        <div className='max-w-md mx-auto'>
            <p className='mt-10 text-sm text-gray-700 -mb-2 font-semibold'>Edit menu items</p>
            {menuItems?.length > 0 && menuItems.map(item => (
                <button className='w-full p-2 flex justify-center items-center my-2 rounded-md outline-none border border-pink-500 hover:opacity-60 duration-300'>{item.itemName}</button>
            ))}
        </div>
    </div>
  )
}

export default MenuItemsPage